@@ -1,53 +1,42 @@
-use serde_json::Value::Number;
+use flowmacro::flow_function;
 use serde_json::{json, Value};
+use serde_json::Value::Number;
 
-use flow_impl_derive::FlowImpl;
-use flowcore::{Implementation, RunAgain, RUN_AGAIN};
+#[flow_function]
+fn _subtract(inputs: &[Value]) -> Result<(Option<Value>, RunAgain)> {
+    let input_a = &inputs[0];
+    let input_b = &inputs[1];
+    let mut value: Option<Value> = None;
 
-#[derive(FlowImpl)]
-/// Subtract one input from another to produce a new output
-#[derive(Debug)]
-pub struct Subtract;
-
-impl Implementation for Subtract {
-    fn run(&self, inputs: &[Value]) -> (Option<Value>, RunAgain) {
-        let input_a = &inputs[0];
-        let input_b = &inputs[1];
-        let mut value: Option<Value> = None;
-
-        match (&input_a, &input_b) {
-            (&Number(ref a), &Number(ref b)) => {
-                if let Some(a_i64) = a.as_i64() {
-                    if let Some(b_i64) = b.as_i64() {
-                        let result = a_i64.checked_sub(b_i64);
-                        if let Some(int) = result {
-                            value = Some(json!(int));
-                        }
-                    }
-                } else if let Some(a_u64) = a.as_u64() {
-                    if let Some(b_u64) = b.as_u64() {
-                        let result = a_u64.checked_sub(b_u64);
-                        if let Some(int) = result {
-                            value = Some(json!(int));
-                        }
-                    }
-                } else if let Some(a_f64) = a.as_f64() {
-                    if let Some(b_f64) = b.as_f64() {
-                        let result = a_f64 - b_f64;
-                        if let Some(f) = serde_json::Number::from_f64(result) {
-                            value = Some(Value::Number(f))
-                        }
-                    }
-                };
+    if let (&Number(ref a), &Number(ref b)) = (&input_a, &input_b) {
+        if let Some(a_i64) = a.as_i64() {
+            if let Some(b_i64) = b.as_i64() {
+                let result = a_i64.checked_sub(b_i64);
+                if let Some(int) = result {
+                    value = Some(json!(int));
+                }
             }
-            (_, _) => {}
-        }
+        } else if let Some(a_u64) = a.as_u64() {
+            if let Some(b_u64) = b.as_u64() {
+                let result = a_u64.checked_sub(b_u64);
+                if let Some(int) = result {
+                    value = Some(json!(int));
+                }
+            }
+        } else if let Some(a_f64) = a.as_f64() {
+            if let Some(b_f64) = b.as_f64() {
+                let result = a_f64 - b_f64;
+                if let Some(f) = serde_json::Number::from_f64(result) {
+                    value = Some(Value::Number(f))
+                }
+            }
+        };
+    }
 
-        if let Some(diff) = value {
-            (Some(json!(diff)), RUN_AGAIN)
-        } else {
-            (None, RUN_AGAIN)
-        }
+    if let Some(diff) = value {
+        Ok((Some(json!(diff)), RUN_AGAIN))
+    } else {
+        Ok((None, RUN_AGAIN))
     }
 }
 
@@ -57,9 +46,7 @@ mod test {
     use serde_json::Value;
     use serde_json::Value::Number;
 
-    use flowcore::Implementation;
-
-    use super::Subtract;
+    use super::_subtract;
 
     fn get_inputs(pair: &(Value, Value, Option<Value>)) -> Vec<Value> {
         vec![pair.0.clone(), pair.1.clone()]
@@ -153,10 +140,8 @@ mod test {
             ),
         ];
 
-        let subtract = Subtract {};
-
         for test in &integer_test_set {
-            let (output, again) = subtract.run(&get_inputs(test));
+            let (output, again) = _subtract(&get_inputs(test)).expect("_subtract() failed");
             assert!(again);
             assert_eq!(output, test.2);
         }
